==> haskell-utf8-string-1.0.1.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-utf8-string.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: utf8-string
version: 1.0.1.1
id: utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
key: utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
license: BSD3
maintainer: emertens@galois.com
homepage: http://github.com/glguy/utf8-string/
synopsis: Support for reading and writing UTF8 Strings
description:
    A UTF8 layer for Strings. The utf8-string
    package provides operations for encoding UTF8
    strings to Word8 lists and back, and for reading and
    writing UTF8 without truncation.
category: Codec
author: Eric Mertens
exposed: True
indefinite: False
exposed-modules:
    Codec.Binary.UTF8.Generic Codec.Binary.UTF8.String
    Data.ByteString.Lazy.UTF8 Data.ByteString.UTF8 Data.String.UTF8
abi: 8d643a529d99a952051170bc6a18d0f2
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/utf8-string-1.0.1.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/utf8-string-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/utf8-string-1.0.1.1
hs-libraries: HSutf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
depends:
    base-4.10.0.0 bytestring-0.10.8.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
haddock-interfaces: /usr/share/doc/haskell-utf8-string/html/utf8-string.haddock
haddock-html: /usr/share/doc/haskell-utf8-string/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-utf8-string-1.0.1.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-utf8-string.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: utf8-string
version: 1.0.1.1
id: utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
key: utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
license: BSD3
maintainer: emertens@galois.com
homepage: http://github.com/glguy/utf8-string/
synopsis: Support for reading and writing UTF8 Strings
description:
    A UTF8 layer for Strings. The utf8-string
    package provides operations for encoding UTF8
    strings to Word8 lists and back, and for reading and
    writing UTF8 without truncation.
category: Codec
author: Eric Mertens
exposed: True
indefinite: False
exposed-modules:
    Codec.Binary.UTF8.Generic Codec.Binary.UTF8.String
    Data.ByteString.Lazy.UTF8 Data.ByteString.UTF8 Data.String.UTF8
abi: 4a40da384793deade7b4b9c9224acdb7
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/utf8-string-1.0.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/utf8-string-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/utf8-string-1.0.1.1
hs-libraries: HSutf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
depends:
    base-4.10.1.0 bytestring-0.10.8.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
haddock-interfaces: /usr/share/doc/haskell-utf8-string/html/utf8-string.haddock
haddock-html: /usr/share/doc/haskell-utf8-string/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
